@@ -12,6 +12,7 @@ import os
 import sys
 import stat
 import errno
+import site
 import tempfile
 import warnings
 from pathlib import Path
@@ -126,7 +127,6 @@ if os.name == 'nt':
         SYSTEM_JUPYTER_PATH = [os.path.join(sys.prefix, 'share', 'jupyter')]
 else:
     SYSTEM_JUPYTER_PATH = [
-        "/usr/local/share/jupyter",
         "/usr/share/jupyter",
     ]
 
@@ -141,14 +141,16 @@ def jupyter_path(*subdirs):
     If the JUPYTER_PREFER_ENV_PATH environment variable is set, the environment-level
     directories will have priority over user-level directories.
 
+    If the Python site.ENABLE_USER_SITE variable is True, we also add the
+    appropriate Python user site subdirectory to the user-level directories.
+
+
     If ``*subdirs`` are given, that subdirectory will be added to each element.
 
     Examples:
 
     >>> jupyter_path()
-    ['~/.local/jupyter', '/usr/local/share/jupyter']
     >>> jupyter_path('kernels')
-    ['~/.local/jupyter/kernels', '/usr/local/share/jupyter/kernels']
     """
 
     paths = []
@@ -161,14 +163,25 @@ def jupyter_path(*subdirs):
         )
 
     # Next is environment or user, depending on the JUPYTER_PREFER_ENV_PATH flag
-    user = jupyter_data_dir()
+    user = [jupyter_data_dir()]
+    if site.ENABLE_USER_SITE:
+        # Check if site.getuserbase() exists to be compatible with virtualenv,
+        # which often does not have this method.
+        if hasattr(site, 'getuserbase'):
+            userbase = site.getuserbase()
+        else:
+            userbase = site.USER_BASE
+        userdir = os.path.join(userbase, 'share', 'jupyter')
+        if userdir not in user:
+            user.append(userdir)
+
     env = [p for p in ENV_JUPYTER_PATH if p not in SYSTEM_JUPYTER_PATH]
 
     if envset('JUPYTER_PREFER_ENV_PATH'):
         paths.extend(env)
-        paths.append(user)
+        paths.extend(user)
     else:
-        paths.append(user)
+        paths.extend(user)
         paths.extend(env)
 
     # finally, system
@@ -197,9 +210,13 @@ ENV_CONFIG_PATH = [os.path.join(sys.prefix, 'etc', 'jupyter')]
 
 def jupyter_config_path():
     """Return the search path for Jupyter config files as a list.
-    
-    If the JUPYTER_PREFER_ENV_PATH environment variable is set, the environment-level
-    directories will have priority over user-level directories.
+
+    If the JUPYTER_PREFER_ENV_PATH environment variable is set, the
+    environment-level directories will have priority over user-level
+    directories.
+
+    If the Python site.ENABLE_USER_SITE variable is True, we also add the
+    appropriate Python user site subdirectory to the user-level directories.
     """
     if os.environ.get('JUPYTER_NO_CONFIG'):
         # jupyter_config_dir makes a blank config when JUPYTER_NO_CONFIG is set.
@@ -215,14 +232,26 @@ def jupyter_config_path():
         )
 
     # Next is environment or user, depending on the JUPYTER_PREFER_ENV_PATH flag
-    user = jupyter_config_dir()
+    user = [jupyter_config_dir()]
+    if site.ENABLE_USER_SITE:
+        # Check if site.getuserbase() exists to be compatible with virtualenv,
+        # which often does not have this method.
+        if hasattr(site, 'getuserbase'):
+            userbase = site.getuserbase()
+        else:
+            userbase = site.USER_BASE
+
+        userdir = os.path.join(userbase, 'etc', 'jupyter')
+        if userdir not in user:
+            user.append(userdir)
+
     env = [p for p in ENV_CONFIG_PATH if p not in SYSTEM_CONFIG_PATH]
 
     if envset('JUPYTER_PREFER_ENV_PATH'):
         paths.extend(env)
-        paths.append(user)
+        paths.extend(user)
     else:
-        paths.append(user)
+        paths.extend(user)
         paths.extend(env)
 
     # Finally, system path
